==> down.php?SDK=iOS_V1.20.2.3.zip: iOS_V1.20.2.3/Sample/Source/AuthV1/AuthViewController.swift <==
//
//  AuthViewController
//  HIVE_SDK_Sample
//
//  Created by jhjang on 03/12/2018.
//  Copyright © 2018 gcp. All rights reserved.
//

import UIKit
import HIVEService

enum AuthApi: String, CaseIterable {
    case initialize = "Initialize"
    case getLoginType = "Get Login Type"
    case login = "Login"
    case showLoginSelection = "Show Login Selection"
    case logout = "Logout"
    case getAccount = "Get Account"
    case showTerms = "Show Terms"
    case checkMaintenance = "Check Maintenance"
    case reset = "reset"
    case setFacebookPermission = "Set Facebook Permission"
    case requestPermissionViewData = "Request Permission View Data"
    case showAdultConfirm = "show Adult Confirm"
    case activeUserStart = "ActiveUser Start - Test"
    case getMyProfile = "get My Profile"
    case requestAsyncRequest = "CS_AsyncRequest"
    case requestSocialRequest = "CS_SocialRequest"
    case showDialog = "showDialog"
    case showDialogPath = "showDialogPath For Peppermint"
    case hiveLogin = "Hive Login"
    case hiveLogout = "Hive Logout"
    case hiveSendMessage = "Hive Send Message"
    case hiveSendInvitation = "Hive Send Invitation"
    case hiveGetInvitationFriend = "Hive Invitation FriendList"
}

class AuthViewController: BaseViewController {
    let apis: [AuthApi] = AuthApi.allCases
    var loginType: AuthLoginType = .guest
    
    var loginActionSheet: UIAlertController {
        let actionSheet = UIAlertController(title: "LoginType", message: "Select Login Type", preferredStyle: .actionSheet)
        
        let cancelAction = UIAlertAction(title: "Cancel", style: .cancel, handler: nil)
        actionSheet.addAction(cancelAction)
        
        for type in AuthLoginType.allCases {
            let action = UIAlertAction(title: type.description, style: .default) { (action) in
                AuthInterface.login(type, handler: { (result, loginType, account, conflictAccount) in
                    let log = """
                    === AuthInterface.login() ===
                    
                    result - \(result)
                    loginType - \(loginType)
                    account - \(String(describing: account))
                    conflictAccount - \(String(describing: conflictAccount))
                    """
                    
                    self.logDelegate?.addLog(log: log)
                })
            }
            
            actionSheet.addAction(action)
        }
        
        return actionSheet
    }
    
    var asyncRequestAlert: UIAlertController {
        let alert = UIAlertController(title: "CS_AsyncRequest", message: "request subPath", preferredStyle: .alert)
        
        let cancelAction = UIAlertAction(title: "Cancel", style: .cancel, handler: nil)
        alert.addAction(cancelAction)
        
        alert.addTextField { (textField) in
            textField.placeholder = "subPath"
        }
        
        alert.addTextField { (textField) in
            textField.placeholder = "requestScheme(=, & 형태)"
        }
        
        let okAction = UIAlertAction(title: "OK", style: .default) { (action) in
            let subPathString : String = alert.textFields?[0].text ?? ""
            let requestDataString : String = alert.textFields?[1].text ?? ""
            var requestDataList : [String:String]? = nil
            
            if requestDataString.count > 0 {
                let requestDataArray = requestDataString.split(separator: "&").map(String.init)
                let requestDataSchemes = requestDataArray.map { $0.split(separator: "=").map(String.init)}
                
                requestDataList = requestDataSchemes.reduce(into:[String:String]()) { result, requestData in
                    result[requestData[0]] = requestData[1]
                }
            }
            
            SocialHiveInterface.requestAsyncRequest(subPathString, requestData: requestDataList, handler: { (result, response) in
                let log = """
                === SocialHiveInterface.requestAsyncRequest(\(subPathString)) ===
                
                result - \(result)
                jsonString - \(String(describing: response))
                """
                
                self.logDelegate?.addLog(log: log)
            })
        }
        
        alert.addAction(okAction)
        
        return alert
    }
    
    var socialRequestAlert: UIAlertController {
        let alert = UIAlertController(title: "CS_SocialRequest", message: "request subPath", preferredStyle: .alert)
        
        let cancelAction = UIAlertAction(title: "Cancel", style: .cancel, handler: nil)
        alert.addAction(cancelAction)
        
        alert.addTextField { (textField) in
            textField.placeholder = "path"
        }
        
        let shareDict = [
            "name" : "name : 게임에서 입력한 name",
            "link" : "http://m.withhive.com/",
            "description" : "description : 게임에서 입력한 description",
            "picture" : "http://image-glb.qpyou.cn/hubweb/contents/%ED%95%98%EC%9D%B4%EB%B8%8C%EC%9A%A9(590x214)_140.png",
            "message" : "tttesttt",
            "title" : "title"
        ]
        
        let okAction = UIAlertAction(title: "OK", style: .default) { (action) in
            let subPathString : String = alert.textFields?[0].text ?? ""
            
            SocialHiveInterface.requestSocialRequest("facebook", actionName: subPathString, requestData: shareDict, handler: { (result, response) in
                let log = """
                === SocialHiveInterface.requestSocialRequest(\(subPathString)) ===
                
                result - \(result)
                jsonString - \(String(describing: response))
                """
                
                self.logDelegate?.addLog(log: log)
            })
        }
        
        alert.addAction(okAction)
        
        return alert
    }
    
    var showDialogPathRequestAlert: UIAlertController {
        let alert = UIAlertController(title: "CS_ShowDialog", message: "request subPath", preferredStyle: .alert)
        
        let cancelAction = UIAlertAction(title: "Cancel", style: .cancel, handler: nil)
        alert.addAction(cancelAction)
        
        alert.addTextField { (textField) in
            textField.placeholder = "path"
        }
        
        let okAction = UIAlertAction(title: "OK", style: .default) { (action) in
            let subPathString : String = alert.textFields?[0].text ?? ""
            
            SocialHiveInterface.showHiveDialogWithPath(subPathString,engageDict: nil, handler: { (result, response) in
                let log = """
                === SocialHiveInterface.requestAsyncRequest(\(subPathString)) ===
                
                result - \(result)
                jsonString - \(String(describing: response))
                """
                
                self.logDelegate?.addLog(log: log)
            })
        }
        
        alert.addAction(okAction)
        
        return alert
    }
    
    var showDialogRequestActionSheet: UIAlertController {
        let actionSheet = UIAlertController(title: "DialogType", message: "Select SocialDialog Type", preferredStyle: .actionSheet)
        
        let cancelAction = UIAlertAction(title: "Cancel", style: .cancel, handler: nil)
        actionSheet.addAction(cancelAction)
        
        for type in DialogType.allCases {
            let action = UIAlertAction(title: type.description, style: .default) { (action) in
                SocialHiveInterface.showHiveDialog(type, vid: "") { (result) in
                    let log = """
                    === SocialHiveInterface.showHiveDialog() ===

                    result - \(result)
                    """

                    self.logDelegate?.addLog(log: log)
                }
            }
            
            actionSheet.addAction(action)
        }
        
        return actionSheet
        
    }
    
    @IBOutlet weak var tableView: UITableView!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        self.tableView.contentInset = UIEdgeInsets.init(top: 44, left: 0, bottom: 0, right: 0)
    }
    
    func callAPI(api: AuthApi) {
        switch api {
        case .initialize:
            AuthInterface.initialize { (result, authInitResult) in
                let log = """
                === AuthInterface.initialize() ===
                
                result - \(result)
                authInitResult - \(String(describing: authInitResult))
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case .getLoginType:
            let loginType = AuthInterface.getLoginType()
            let log = """
            === AuthInterface.getLoginType() ===
            
            loginType - \(loginType)
            """
            
            self.logDelegate?.addLog(log: log)
        case .login:
            self.present(self.loginActionSheet, animated: true, completion: nil)
        case .showLoginSelection:
            preconditionFailure()
        case .logout:
            AuthInterface.logout { (result) in
                let log = """
                === AuthInterface.logout() ===
                
                result - \(result)
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case .getAccount:
            let account = AuthInterface.getAccount()
            
            let log = """
            === AuthInterface.getAccount() ===
            
            account - \(String(describing: account))
            """
            
            self.logDelegate?.addLog(log: log)
        case .showTerms:
            AuthInterface.showTerms { (result) in
                let log = """
                === AuthInterface.showTerms() ===
                
                result - \(result)
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case .checkMaintenance:
            AuthInterface.checkMaintenance(true) { (result, maintenanceInfo) in
                let log = """
                === AuthInterface.checkMaintenance() ===
                
                result - \(result)
                maintenance - \(String(describing: maintenanceInfo))
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case .reset:
            preconditionFailure()
        case .setFacebookPermission:
            preconditionFailure()
        case .requestPermissionViewData:
            AuthInterface.requestPermissionViewData { (result, permissionData) in
                let log = """
                === AuthInterface.requestPermissionViewData() ===
                
                result - \(result)
                permissionData - \(String(describing: permissionData))
                """
                
                self.logDelegate?.addLog(log: log)
            };
        case.showAdultConfirm:
            AuthInterface.showAdultConfirm { (result) in
                let log = "result - \(result)"

                self.logDelegate?.addLog(log: log)
            }
        case .activeUserStart:
            let userAgreeHander:AuthUserAgreeResultHandler = { (result, userAgreeType) in
                let log = """
                === AuthInterface.activeUserStart() - UserAgreeHandler ===
                
                result - \(result)
                userAgreeType - \(userAgreeType.rawValue)
                """
                self.logDelegate?.addLog(log: log)
            }
            
            ConfigurationInterface.setZone(.real)
            
            AuthInterface.activeUserStartWithoutNotice(true, userAgreeHandler: userAgreeHander) { (result, authInitResult) in
                let log = """
                === AuthInterface.activeUserStart() - ActiveUserHandler ===

                result - \(result)
                authInitResult - \(authInitResult.rawValue)
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case.getMyProfile:
            SocialHiveInterface.getMyProfile { (result, profile) in
                let profileFirst = profile?.first ?? ProfileHive()
                let log = """
                === ocialHiveInterface..getMyProfile() ===
                
                result - \(result)
                profile - \(profileFirst.description)
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case.requestAsyncRequest:
            self.present(self.asyncRequestAlert, animated: true, completion: nil)
        case.requestSocialRequest:
            self.present(self.socialRequestAlert, animated: true, completion: nil)
        case .showDialog:
            self.present(self.showDialogRequestActionSheet, animated: true, completion: nil)
        case.showDialogPath:
            self.present(self.showDialogPathRequestAlert, animated: true, completion: nil)
        case.hiveLogin:
            AuthInterface.hubAuthLogin() { (result, response) in
                let log = """
                === SocialHiveInterface.hiveAuthLogin() ===
                
                result - \(result)
                jsonString - \(String(describing: response))
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case.hiveLogout:
            AuthInterface.hubAuthLogout() { (result, response) in
                let log = """
                === SocialHiveInterface.hiveAuthLogin() ===
                
                result - \(result)
                jsonString - \(String(describing: response))
                """
                self.logDelegate?.addLog(log: log)
            }
        case .hiveSendMessage:
            
            let today = NSDate() //현재 시각 구하기
            let dateFormatter = DateFormatter()
            dateFormatter.dateFormat = "yyyy년 M월 d일 hh:mm:ss"
            let dateString = dateFormatter.string(from: today as Date)
            
            let messageContent = MessageContent(vid: "", uid: "217594620", message: "Test From Daun Joung \(dateString)", imageUrl: nil, thumbnailImageUrl: nil, usePush: true)
            SocialHiveInterface.sendMessage(messageContent) { (result) in
                let log = """
                === SocialHiveInterface.sendMessage() ===
                
                result - \(result)
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case .hiveSendInvitation:
            
            let today = NSDate() //현재 시각 구하기
            let dateFormatter = DateFormatter()
            dateFormatter.dateFormat = "yyyy년 M월 d일 hh:mm:ss"
            let dateString = dateFormatter.string(from: today as Date)
            
            let messageContent = MessageContent(vid: "", uid: "161807262", message: "Test From Daun Joung \(dateString)", imageUrl: nil, thumbnailImageUrl: nil, usePush: true)
            SocialHiveInterface.sendInvitationMessage(messageContent) { (result) in
                let log = """
                === SocialHiveInterface.sendInvitationMessage() ===
                
                result - \(result)
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case .hiveGetInvitationFriend:
            SocialHiveInterface.getFriends(.invited) { (result, profiles) in
                let log = """
                === SocialHiveInterface.getFriends() ===
                
                result - \(result)
                """
                
                self.logDelegate?.addLog(log: log)
                
            }
        }
    }
}

extension AuthViewController: UITableViewDelegate, UITableViewDataSource {
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return self.apis.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        guard let cell = tableView.dequeueReusableCell(withIdentifier: "ApiCell") as? AuthTableViewCell else {
            preconditionFailure("Not supported cell type")
        }
        
        cell.configureCell(api: self.apis[indexPath.row])
        
        return cell
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        self.callAPI(api: apis[indexPath.row])
        tableView.deselectRow(at: indexPath, animated: true)
    }
}

==> down.php?SDK=iOS_V1.20.3.2.zip: iOS_V1.20.3.2/Sample/Source/AuthV1/AuthViewController.swift <==
//
//  AuthViewController
//  HIVE_SDK_Sample
//
//  Created by jhjang on 03/12/2018.
//  Copyright © 2018 gcp. All rights reserved.
//

import UIKit
import HIVEService

// swiftlint:disable type_body_length

enum AuthApi: String, CaseIterable {
    case initialize = "Initialize"
    case getLoginType = "Get Login Type"
    case login = "Login"
    case showLoginSelection = "Show Login Selection"
    case logout = "Logout"
    case getAccount = "Get Account"
    case showTerms = "Show Terms"
    case checkMaintenance = "Check Maintenance"
    case reset = "reset"
    case setFacebookPermission = "Set Facebook Permission"
    case requestPermissionViewData = "Request Permission View Data"
    case showAdultConfirm = "show Adult Confirm"
    case activeUserStart = "ActiveUser Start - Test"
    case getMyProfile = "get My Profile"
    case requestAsyncRequest = "CS_AsyncRequest"
    case requestSocialRequest = "CS_SocialRequest"
    case showDialog = "showDialog"
    case showDialogPath = "showDialogPath For Peppermint"
    case hiveLogin = "Hive Login"
    case hiveLogout = "Hive Logout"
    case hiveSendMessage = "Hive Send Message"
    case hiveSendInvitation = "Hive Send Invitation"
    case hiveGetInvitationFriend = "Hive Invitation FriendList"
}

class AuthViewController: BaseViewController {
    let apis: [AuthApi] = AuthApi.allCases
    var loginType: AuthLoginType = .guest
    
    var loginActionSheet: UIAlertController {
        let actionSheet = UIAlertController(title: "LoginType", message: "Select Login Type", preferredStyle: .actionSheet)
        
        let cancelAction = UIAlertAction(title: "Cancel", style: .cancel, handler: nil)
        actionSheet.addAction(cancelAction)
        
        for type in AuthLoginType.allCases {
            let action = UIAlertAction(title: type.description, style: .default) { (_) in
                AuthInterface.login(type, handler: { (result, loginType, account, conflictAccount) in
                    let log = """
                    === AuthInterface.login() ===
                    
                    result - \(result)
                    loginType - \(loginType)
                    account - \(String(describing: account))
                    conflictAccount - \(String(describing: conflictAccount))
                    """
                    
                    self.logDelegate?.addLog(log: log)
                })
            }
            
            actionSheet.addAction(action)
        }
        
        return actionSheet
    }
    
    var asyncRequestAlert: UIAlertController {
        let alert = UIAlertController(title: "CS_AsyncRequest", message: "request subPath", preferredStyle: .alert)
        
        let cancelAction = UIAlertAction(title: "Cancel", style: .cancel, handler: nil)
        alert.addAction(cancelAction)
        
        alert.addTextField { (textField) in
            textField.placeholder = "subPath"
        }
        
        alert.addTextField { (textField) in
            textField.placeholder = "requestScheme(=, & 형태)"
        }
        
        let okAction = UIAlertAction(title: "OK", style: .default) { (_) in
            let subPathString: String = alert.textFields?[0].text ?? ""
            let requestDataString: String = alert.textFields?[1].text ?? ""
            var requestDataList: [String: String]? = nil
            
            if requestDataString.count > 0 {
                let requestDataArray = requestDataString.split(separator: "&").map(String.init)
                let requestDataSchemes = requestDataArray.map { $0.split(separator: "=").map(String.init)}
                
                requestDataList = requestDataSchemes.reduce(into: [String: String]()) { result, requestData in
                    result[requestData[0]] = requestData[1]
                }
            }
            
            _ = SocialHiveInterface.requestAsyncRequest(subPathString, requestData: requestDataList, handler: { result, response in
                let log = """
                === SocialHiveInterface.requestAsyncRequest(\(subPathString)) ===
                
                result - \(result)
                jsonString - \(String(describing: response))
                """
                
                self.logDelegate?.addLog(log: log)
            })
        }
        
        alert.addAction(okAction)
        
        return alert
    }
    
    var socialRequestAlert: UIAlertController {
        let alert = UIAlertController(title: "CS_SocialRequest", message: "request subPath", preferredStyle: .alert)
        
        let cancelAction = UIAlertAction(title: "Cancel", style: .cancel, handler: nil)
        alert.addAction(cancelAction)
        
        alert.addTextField { (textField) in
            textField.placeholder = "path"
        }
        
        let shareDict = [
            "name": "name : 게임에서 입력한 name",
            "link": "http://m.withhive.com/",
            "description": "description : 게임에서 입력한 description",
            "picture": "http://image-glb.qpyou.cn/hubweb/contents/%ED%95%98%EC%9D%B4%EB%B8%8C%EC%9A%A9(590x214)_140.png",
            "message": "tttesttt",
            "title": "title"
        ]
        
        let okAction = UIAlertAction(title: "OK", style: .default) { (_) in
            let subPathString: String = alert.textFields?[0].text ?? ""
            
            _ = SocialHiveInterface.requestSocialRequest("facebook", actionName: subPathString, requestData: shareDict, handler: { result, response in
                let log = """
                === SocialHiveInterface.requestSocialRequest(\(subPathString)) ===
                
                result - \(result)
                jsonString - \(String(describing: response))
                """
                
                self.logDelegate?.addLog(log: log)
            })
        }
        
        alert.addAction(okAction)
        
        return alert
    }
    
    var showDialogPathRequestAlert: UIAlertController {
        let alert = UIAlertController(title: "CS_ShowDialog", message: "request subPath", preferredStyle: .alert)
        
        let cancelAction = UIAlertAction(title: "Cancel", style: .cancel, handler: nil)
        alert.addAction(cancelAction)
        
        alert.addTextField { (textField) in
            textField.placeholder = "path"
        }
        
        let okAction = UIAlertAction(title: "OK", style: .default) { (_) in
            let subPathString: String = alert.textFields?[0].text ?? ""
            
            _ = SocialHiveInterface.showHiveDialogWithPath(subPathString, engageDict: nil, handler: { result, response in
                let log = """
                === SocialHiveInterface.requestAsyncRequest(\(subPathString)) ===
                
                result - \(result)
                jsonString - \(String(describing: response))
                """
                
                self.logDelegate?.addLog(log: log)
            })
        }
        
        alert.addAction(okAction)
        
        return alert
    }
    
    var showDialogRequestActionSheet: UIAlertController {
        let actionSheet = UIAlertController(title: "DialogType", message: "Select SocialDialog Type", preferredStyle: .actionSheet)
        
        let cancelAction = UIAlertAction(title: "Cancel", style: .cancel, handler: nil)
        actionSheet.addAction(cancelAction)
        
        for type in DialogType.allCases {
            let action = UIAlertAction(title: type.description, style: .default) { (_) in
                SocialHiveInterface.showHiveDialog(type, vid: "") { (result) in
                    let log = """
                    === SocialHiveInterface.showHiveDialog() ===

                    result - \(result)
                    """

                    self.logDelegate?.addLog(log: log)
                }
            }
            
            actionSheet.addAction(action)
        }
        
        return actionSheet
        
    }
    
    @IBOutlet weak var tableView: UITableView!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        self.tableView.contentInset = UIEdgeInsets.init(top: 44, left: 0, bottom: 0, right: 0)
    }
    
    func callAPI(api: AuthApi) {
        switch api {
        case .initialize:
            AuthInterface.initialize { (result, authInitResult) in
                let log = """
                === AuthInterface.initialize() ===
                
                result - \(result)
                authInitResult - \(String(describing: authInitResult))
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case .getLoginType:
            let loginType = AuthInterface.getLoginType()
            let log = """
            === AuthInterface.getLoginType() ===
            
            loginType - \(loginType)
            """
            
            self.logDelegate?.addLog(log: log)
        case .login:
            self.present(self.loginActionSheet, animated: true, completion: nil)
        case .showLoginSelection:
            preconditionFailure()
        case .logout:
            AuthInterface.logout { (result) in
                let log = """
                === AuthInterface.logout() ===
                
                result - \(result)
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case .getAccount:
            let account = AuthInterface.getAccount()
            
            let log = """
            === AuthInterface.getAccount() ===
            
            account - \(String(describing: account))
            """
            
            self.logDelegate?.addLog(log: log)
        case .showTerms:
            AuthInterface.showTerms { (result) in
                let log = """
                === AuthInterface.showTerms() ===
                
                result - \(result)
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case .checkMaintenance:
            AuthInterface.checkMaintenance(true) { (result, maintenanceInfo) in
                let log = """
                === AuthInterface.checkMaintenance() ===
                
                result - \(result)
                maintenance - \(String(describing: maintenanceInfo))
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case .reset:
            preconditionFailure()
        case .setFacebookPermission:
            preconditionFailure()
        case .requestPermissionViewData:
            AuthInterface.requestPermissionViewData { (result, permissionData) in
                let log = """
                === AuthInterface.requestPermissionViewData() ===
                
                result - \(result)
                permissionData - \(String(describing: permissionData))
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case.showAdultConfirm:
            AuthInterface.showAdultConfirm { (result) in
                let log = "result - \(result)"

                self.logDelegate?.addLog(log: log)
            }
        case .activeUserStart:
            let userAgreeHander: AuthUserAgreeResultHandler = { (result, userAgreeType) in
                let log = """
                === AuthInterface.activeUserStart() - UserAgreeHandler ===
                
                result - \(result)
                userAgreeType - \(userAgreeType.rawValue)
                """
                self.logDelegate?.addLog(log: log)
            }
            
            ConfigurationInterface.setZone(.real)
            
            AuthInterface.activeUserStartWithoutNotice(true, userAgreeHandler: userAgreeHander) { (result, authInitResult) in
                let log = """
                === AuthInterface.activeUserStart() - ActiveUserHandler ===

                result - \(result)
                authInitResult - \(authInitResult.rawValue)
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case.getMyProfile:
            SocialHiveInterface.getMyProfile { (result, profile) in
                let profileFirst = profile?.first ?? ProfileHive()
                let log = """
                === ocialHiveInterface..getMyProfile() ===
                
                result - \(result)
                profile - \(profileFirst.description)
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case.requestAsyncRequest:
            self.present(self.asyncRequestAlert, animated: true, completion: nil)
        case.requestSocialRequest:
            self.present(self.socialRequestAlert, animated: true, completion: nil)
        case .showDialog:
            self.present(self.showDialogRequestActionSheet, animated: true, completion: nil)
        case.showDialogPath:
            self.present(self.showDialogPathRequestAlert, animated: true, completion: nil)
        case.hiveLogin:
            _ = AuthInterface.hubAuthLogin { result, response in
                let log = """
                === SocialHiveInterface.hiveAuthLogin() ===
                
                result - \(result)
                jsonString - \(String(describing: response))
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case.hiveLogout:
            _ = AuthInterface.hubAuthLogout { result, response in
                let log = """
                === SocialHiveInterface.hiveAuthLogin() ===
                
                result - \(result)
                jsonString - \(String(describing: response))
                """
                self.logDelegate?.addLog(log: log)
            }
        case .hiveSendMessage:
            
            let today = NSDate() // 현재 시각 구하기
            let dateFormatter = DateFormatter()
            dateFormatter.dateFormat = "yyyy년 M월 d일 hh:mm:ss"
            let dateString = dateFormatter.string(from: today as Date)
            
            let messageContent = MessageContent(
                vid: "",
                uid: "217594620",
                message: "Test From Daun Joung \(dateString)",
                imageUrl: nil,
                thumbnailImageUrl: nil,
                usePush: true
            )
            
            SocialHiveInterface.sendMessage(messageContent) { (result) in
                let log = """
                === SocialHiveInterface.sendMessage() ===
                
                result - \(result)
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case .hiveSendInvitation:
            
            let today = NSDate() // 현재 시각 구하기
            let dateFormatter = DateFormatter()
            dateFormatter.dateFormat = "yyyy년 M월 d일 hh:mm:ss"
            let dateString = dateFormatter.string(from: today as Date)
            
            let messageContent = MessageContent(
                vid: "",
                uid: "161807262",
                message: "Test From Daun Joung \(dateString)",
                imageUrl: nil,
                thumbnailImageUrl: nil,
                usePush: true
            
            )
            SocialHiveInterface.sendInvitationMessage(messageContent) { (result) in
                let log = """
                === SocialHiveInterface.sendInvitationMessage() ===
                
                result - \(result)
                """
                
                self.logDelegate?.addLog(log: log)
            }
        case .hiveGetInvitationFriend:
            SocialHiveInterface.getFriends(.invited) { (result, _) in
                let log = """
                === SocialHiveInterface.getFriends() ===
                
                result - \(result)
                """
                
                self.logDelegate?.addLog(log: log)
                
            }
        }
    }
}

extension AuthViewController: UITableViewDelegate, UITableViewDataSource {
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        self.apis.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        guard let cell = tableView.dequeueReusableCell(withIdentifier: "ApiCell") as? AuthTableViewCell else {
            preconditionFailure("Not supported cell type")
        }
        
        cell.configureCell(api: self.apis[indexPath.row])
        
        return cell
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        self.callAPI(api: apis[indexPath.row])
        tableView.deselectRow(at: indexPath, animated: true)
    }
}
